# Contributors

- Olesya (@ovbondarenko): ElasticSearch & ALBERT-based DL transformers for QA (winner of Duchess's Joan of Arc award May 2020)
- Kendra: semantic search of article titles
- Mohammed: web application
- Maria: product development
- Aliya (@beetpoet) working on a new *mystery* feature
- Travis (@travis-harper): markhov chain reply selection and other data science enhancements
- Nima (@hulkgeek): question answering bot based on his state of the art question classifier
- Xavier (@spirovanni): employment counselor for workforce.org and the city of San Diego
- Hobson (@hobson): infrastructure (CI, webapp) and framework features (nltk->spacy, USE vectors)
- Alex (@alxrsngrtn): will submit a CL from time to time (winner of Duchess's Jester award May 2020)
- Jose (@jorobins): Yes/No bot
- You: What big chatbot idea would you like to make a reality?

